==> xl-plugin-manager-10.0.3-sources.jar: com/xebialabs/plugin/manager/metadata/ArtifactId.scala <==
package com.xebialabs.plugin.manager.metadata

import akka.http.scaladsl.marshallers.sprayjson.SprayJsonSupport
import com.typesafe.config.Config
import com.xebialabs.plugin.manager.{LocalPluginManager, PluginId, requireProperFilename}
import spray.json._

import scala.util.{Failure, Success, Try}

case class ArtifactId(groupId: String, artifactId: String, version: Version, repository: Option[String] = None) {
  requireProperFilename(groupId, "groupId")
  requireProperFilename(artifactId, "artifactId")
  repository.foreach(r => {
    requireProperFilename(r, "repository")
    require(r != LocalPluginManager.name)
  })
}

object ArtifactId {
  implicit class ArtifactIdOps(val artifactId: ArtifactId) extends AnyVal {
    def id: String =
      s"${artifactId.repository.getOrElse(LocalPluginManager.name)}:${artifactId.groupId}:${artifactId.artifactId}-${artifactId.version.id}"

    def toPluginId(classifier: Option[String] = None): Option[PluginId] = artifactId.repository match {
      case None if artifactId.groupId == PluginId.localGroupId =>
        Some(toLocal)
      case Some(repo) if artifactId.groupId != PluginId.localGroupId && repo != LocalPluginManager.name =>
        Some(toArtifact(repo, classifier))
      case _ =>
        None
    }

    def toArtifact(repositoryName: String, classifier: Option[String] = None): PluginId.Artifact =
        PluginId.Artifact.parsed(repositoryName, artifactId.groupId, artifactId.artifactId, artifactId.version, classifier)

    def toLocal: PluginId.LocalFile =
      PluginId.LocalFile.parsed(artifactId.artifactId, Some(artifactId.version))
  }

  def fromConfig(repository: Option[String] = None)(repositoryConfig: Config): Try[ArtifactId] = for {
    groupId <- Try(repositoryConfig.getString("group-id"))
    artifactId <- Try(repositoryConfig.getString("artifact-id"))
    versionString <- Try(repositoryConfig.getString("version"))
    version <- Version.fromString(versionString) match {
      case None => Failure(new IllegalArgumentException(s"Cannot parse version: '$versionString'"))
      case Some(v) => Success(v)
    }
  } yield ArtifactId(groupId, artifactId, version, repository)

  trait Protocol extends SprayJsonSupport with DefaultJsonProtocol
    with Version.Protocol {

    val artifactIdReader: RootJsonReader[ArtifactId] = {
      case obj: JsObject =>
        obj.getFields("groupId", "artifactId", "version") match {
          case Seq(JsString(groupId), JsString(artifactId), version) =>
            ArtifactId(groupId, artifactId, version.convertTo[Version])
          case wrong =>
            deserializationError(s"Cannot parse artifactId object: $wrong")
        }
      case unknown =>
        deserializationError(s"Cannot parse artifactId object: $unknown")
    }

    val artifactIdWriter: RootJsonWriter[ArtifactId] = (id: ArtifactId) => JsObject(
      "groupId" -> id.groupId.toJson,
      "artifactId" -> id.artifactId.toJson,
      "version" -> id.version.toJson
    )

    implicit val artifactIdFormat: RootJsonFormat[ArtifactId] = rootJsonFormat(artifactIdReader, artifactIdWriter)
  }
}

==> xl-plugin-manager-10.3.9-sources.jar: com/xebialabs/plugin/manager/metadata/ArtifactId.scala <==
package com.xebialabs.plugin.manager.metadata

import akka.http.scaladsl.marshallers.sprayjson.SprayJsonSupport
import com.xebialabs.plugin.manager.{LocalPluginManager, PluginId, requireProperFilename}
import spray.json._

case class ArtifactId(groupId: String, artifactId: String, version: Version, repository: Option[String] = None) {
  requireProperFilename(groupId, "groupId")
  requireProperFilename(artifactId, "artifactId")
  repository.foreach(r => {
    requireProperFilename(r, "repository")
  })
}

object ArtifactId {
  implicit class ArtifactIdOps(val artifactId: ArtifactId) extends AnyVal {
    def id: String =
      s"${artifactId.repository.getOrElse(LocalPluginManager.name)}:${artifactId.groupId}:${artifactId.artifactId}-${artifactId.version.id}"

    def toPluginId(classifier: Option[String] = None): Option[PluginId] = artifactId.repository match {
      case None if artifactId.groupId == PluginId.localGroupId =>
        Some(toLocal)
      case Some(repo) if artifactId.groupId != PluginId.localGroupId && repo != LocalPluginManager.name =>
        Some(toArtifact(repo, classifier))
      case _ =>
        None
    }

    def toArtifact(repositoryName: String, classifier: Option[String] = None): PluginId.Artifact =
      PluginId.Artifact.parsed(repositoryName, artifactId.groupId, artifactId.artifactId, artifactId.version, classifier)

    def toArtifact: PluginId.Artifact =
      PluginId.Artifact.parsed(artifactId.repository.getOrElse(PluginId.localGroupId), artifactId.groupId, artifactId.artifactId, artifactId.version, None)

    def toLocal: PluginId.LocalFile =
      PluginId.LocalFile.parsed(artifactId.artifactId, Some(artifactId.version))
  }

  trait Protocol extends SprayJsonSupport with DefaultJsonProtocol
    with Version.Protocol {

    val artifactIdReader: RootJsonReader[ArtifactId] = {
      case obj: JsObject =>
        obj.getFields("groupId", "artifactId", "version") match {
          case Seq(JsString(groupId), JsString(artifactId), version) =>
            ArtifactId(groupId, artifactId, version.convertTo[Version])
          case wrong =>
            deserializationError(s"Cannot parse artifactId object: $wrong")
        }
      case unknown =>
        deserializationError(s"Cannot parse artifactId object: $unknown")
    }

    val artifactIdWriter: RootJsonWriter[ArtifactId] = (id: ArtifactId) => JsObject(
      "groupId" -> id.groupId.toJson,
      "artifactId" -> id.artifactId.toJson,
      "version" -> id.version.toJson
    )

    implicit val artifactIdFormat: RootJsonFormat[ArtifactId] = rootJsonFormat(artifactIdReader, artifactIdWriter)
  }
}
